@@ -1,12 +1,9 @@
+import setuptools
+import setuptools.dist
 import distutils.command.bdist_rpm
 import distutils.command.build
 import distutils.command.install
-import distutils.core
-import distutils.dir_util
-import distutils.dist
-import distutils.errors
 import distutils.log
-import distutils.version
 import os
 import sys
 import sysconfig
@@ -17,6 +14,7 @@ from .freezer import Freezer
 from .module import ConstantsModule
 
 if sys.platform == "win32":
+    import winreg
     from .windist import bdist_msi
 elif sys.platform == "darwin":
     from .macdist import bdist_dmg, bdist_mac
@@ -31,10 +29,10 @@ __all__ = [
 ]
 
 
-class Distribution(distutils.dist.Distribution):
+class Distribution(setuptools.dist.Distribution):
     def __init__(self, attrs):
         self.executables = []
-        distutils.dist.Distribution.__init__(self, attrs)
+        super().__init__(attrs)
 
 
 class bdist_rpm(distutils.command.bdist_rpm.bdist_rpm):
@@ -73,10 +71,14 @@ class build(distutils.command.build.build):
             self.build_exe = os.path.join(self.build_base, dir_name)
 
 
-class build_exe(distutils.core.Command):
+class build_exe(setuptools.Command):
     description = "build executables from Python scripts"
     user_options = [
-        ("build-exe=", "b", "directory for built executables"),
+        (
+            "build-exe=",
+            "b",
+            "directory for built executables and dependent files",
+        ),
         (
             "optimize=",
             "O",
@@ -85,42 +87,33 @@ class build_exe(distutils.core.Command):
         ),
         ("excludes=", "e", "comma-separated list of modules to exclude"),
         ("includes=", "i", "comma-separated list of modules to include"),
-        ("packages=", "p", "comma-separated list of packages to include"),
+        (
+            "packages=",
+            "p",
+            "comma-separated list of packages to include, "
+            "which includes all submodules in the package",
+        ),
         ("namespace-packages=", None, "[DEPRECATED]"),
         (
             "replace-paths=",
             None,
-            "comma-separated list of paths to replace in included modules",
+            "comma-separated list of paths to replace in included modules, "
+            "using the form <search>=<replace>",
         ),
         ("path=", None, "comma-separated list of paths to search"),
         ("no-compress", None, "create a zipfile with no compression"),
         ("constants=", None, "comma-separated list of constants to include"),
-        (
-            "include-files=",
-            "f",
-            "list of tuples of additional files to include in distribution",
-        ),
-        (
-            "include-msvcr=",
-            None,
-            "include the Microsoft Visual C runtime files",
-        ),
-        (
-            "zip-includes=",
-            None,
-            "list of tuples of additional files to include in zip file",
-        ),
         (
             "bin-includes",
             None,
-            "list of names of files to include when determining "
-            "dependencies of binary files",
+            "list of files to include when determining "
+            "dependencies of binary files that would normally be excluded",
         ),
         (
             "bin-excludes",
             None,
-            "list of names of files to exclude when determining "
-            "dependencies of binary files",
+            "list of files to exclude when determining "
+            "dependencies of binary files that would normally be included",
         ),
         (
             "bin-path-includes",
@@ -134,6 +127,16 @@ class build_exe(distutils.core.Command):
             "list of paths from which to exclude files when determining "
             "dependencies of binary files",
         ),
+        (
+            "include-files=",
+            "f",
+            "list of tuples of additional files to include in distribution",
+        ),
+        (
+            "zip-includes=",
+            None,
+            "list of tuples of additional files to include in zip file",
+        ),
         (
             "zip-include-packages=",
             None,
@@ -163,6 +166,11 @@ class build_exe(distutils.core.Command):
             " level 2: suppress missing missing-module warnings"
             " level 3: suppress all warning messages",
         ),
+        (
+            "include-msvcr=",
+            None,
+            "include the Microsoft Visual C runtime files",
+        ),
     ]
     boolean_options = ["no-compress", "include_msvcr", "silent"]
 
@@ -171,25 +179,26 @@ class build_exe(distutils.core.Command):
         if source_dir is not None:
             sys.path.insert(0, source_dir)
 
-    def build_extension(self, name, moduleName=None):
-        if moduleName is None:
-            moduleName = name
+    def build_extension(self, name, module_name=None):
+        if module_name is None:
+            module_name = name
         source_dir = getattr(self, name.lower())
         if source_dir is None:
-            return
+            return None
         orig_dir = os.getcwd()
         script_args = ["build"]
         command = self.distribution.get_command_obj("build")
         if command.compiler is not None:
-            script_args.append("--compiler=%s" % command.compiler)
+            script_args.append(f"--compiler={command.compiler}")
         os.chdir(source_dir)
         distutils.log.info("building '%s' extension in '%s'", name, source_dir)
-        distribution = distutils.core.run_setup("setup.py", script_args)
-        modules = [m for m in distribution.ext_modules if m.name == moduleName]
+        distribution = setuptools.run_setup("setup.py", script_args)
+        modules = [
+            m for m in distribution.ext_modules if m.name == module_name
+        ]
         if not modules:
-            message_format = "no module named '%s' in '%s'"
-            raise distutils.errors.DistutilsSetupError(
-                message_format % (moduleName, source_dir)
+            raise setuptools.dist.DistutilsSetupError(
+                "no module named '{module_name}' in '{source_dir}'"
             )
         command = distribution.get_command_obj("build_ext")
         command.ensure_finalized()
@@ -202,7 +211,9 @@ class build_exe(distutils.core.Command):
         if dir_name not in sys.path:
             sys.path.insert(0, dir_name)
         return os.path.join(
-            source_dir, command.build_lib, command.get_ext_filename(moduleName)
+            source_dir,
+            command.build_lib,
+            command.get_ext_filename(module_name),
         )
 
     def initialize_options(self):
@@ -210,17 +221,18 @@ class build_exe(distutils.core.Command):
             "excludes",
             "includes",
             "packages",
-            "namespace_packages",
             "replace_paths",
             "constants",
-            "include_files",
-            "zip_includes",
             "bin_excludes",
             "bin_includes",
             "bin_path_includes",
             "bin_path_excludes",
+            "include_files",
+            "zip_includes",
             "zip_include_packages",
             "zip_exclude_packages",
+            # DEPRECATED
+            "namespace_packages",
         ]
 
         for option in self.list_options:
@@ -287,17 +299,17 @@ class build_exe(distutils.core.Command):
             self.optimize,
             self.path,
             self.build_exe,
-            includeMSVCR=self.include_msvcr,
-            includeFiles=self.include_files,
             binIncludes=self.bin_includes,
             binExcludes=self.bin_excludes,
-            zipIncludes=self.zip_includes,
-            silent=self.silent_setting,
             binPathIncludes=self.bin_path_includes,
             binPathExcludes=self.bin_path_excludes,
-            metadata=metadata,
+            includeFiles=self.include_files,
+            zipIncludes=self.zip_includes,
             zipIncludePackages=self.zip_include_packages,
             zipExcludePackages=self.zip_exclude_packages,
+            silent=self.silent_setting,
+            metadata=metadata,
+            includeMSVCR=self.include_msvcr,
         )
 
         # keep freezer around so that its data case be used in bdist_mac phase
@@ -305,7 +317,7 @@ class build_exe(distutils.core.Command):
         freezer.Freeze()
 
     def set_source_location(self, name, *pathParts):
-        env_name = "%s_BASE" % name.upper()
+        env_name = f"{name.upper()}_BASE"
         attr_name = name.lower()
         source_dir = getattr(self, attr_name)
         if source_dir is None:
@@ -338,8 +350,6 @@ class install(distutils.command.install.install):
 
     def finalize_options(self):
         if self.prefix is None and sys.platform == "win32":
-            import winreg
-
             key = winreg.OpenKey(
                 winreg.HKEY_LOCAL_MACHINE,
                 r"Software\Microsoft\Windows\CurrentVersion",
@@ -360,10 +370,10 @@ class install(distutils.command.install.install):
             else:
                 metadata = self.distribution.metadata
                 dir_name = f"{metadata.name}-{metadata.version}"
-                self.install_exe = "$base/lib/%s" % dir_name
+                self.install_exe = f"$base/lib/{dir_name}"
 
 
-class install_exe(distutils.core.Command):
+class install_exe(setuptools.Command):
     description = "install executables built from Python scripts"
     user_options = [
         ("install-dir=", "d", "directory to install executables to"),
@@ -434,4 +444,4 @@ def setup(**attrs):
     _AddCommandClass(command_classes, "build_exe", build_exe)
     _AddCommandClass(command_classes, "install", install)
     _AddCommandClass(command_classes, "install_exe", install_exe)
-    distutils.core.setup(**attrs)
+    setuptools.setup(**attrs)
