@@ -2,7 +2,6 @@
 Base class for finding modules.
 """
 
-import dis
 from importlib.abc import ExecutionLoader
 import importlib.machinery
 import logging
@@ -19,6 +18,7 @@ from .module import ConstantsModule, Module
 
 
 BUILD_LIST = opcode.opmap["BUILD_LIST"]
+EXTENDED_ARG = opcode.opmap["EXTENDED_ARG"]
 INPLACE_ADD = opcode.opmap["INPLACE_ADD"]
 LOAD_CONST = opcode.opmap["LOAD_CONST"]
 IMPORT_NAME = opcode.opmap["IMPORT_NAME"]
@@ -28,6 +28,8 @@ STORE_FAST = opcode.opmap["STORE_FAST"]
 STORE_NAME = opcode.opmap["STORE_NAME"]
 STORE_GLOBAL = opcode.opmap["STORE_GLOBAL"]
 STORE_OPS = (STORE_NAME, STORE_GLOBAL)
+HAVE_ARGUMENT = opcode.HAVE_ARGUMENT
+
 
 DeferredList = List[Tuple[Module, Module, List[str]]]
 
@@ -121,7 +123,7 @@ class ModuleFinder:
                 and module.name not in self.zip_exclude_packages
                 or module.name in self.zip_include_packages
             ):
-                module.in_file_system = False
+                module.in_file_system = 0
         if module.path is None and path is not None:
             module.path = [Path(p) for p in path]
         if module.file is None and file_name is not None:
@@ -358,9 +360,9 @@ class ModuleFinder:
         parent: Optional[Module] = None,
     ) -> Optional[Module]:
         """Load the module, searching the module spec."""
-        spec: Optional[importlib.machinery.ModuleSpec]
-        loader: ExecutionLoader
-        module: Module
+        spec: Optional[importlib.machinery.ModuleSpec] = None
+        loader: Optional[ExecutionLoader] = None
+        module: Optional[Module] = None
 
         if isinstance(path, str):
             # Include file as module
@@ -372,8 +374,6 @@ class ModuleFinder:
                 loader = importlib.machinery.SourcelessFileLoader(name, path)
             elif ext in importlib.machinery.EXTENSION_SUFFIXES:
                 loader = importlib.machinery.ExtensionFileLoader(name, path)
-            else:
-                loader = None
         else:
             # Find modules to load
             if path:
@@ -385,20 +385,21 @@ class ModuleFinder:
             except KeyError:
                 if parent:
                     # some packages use a directory with vendored modules
-                    # without an __init__py and are not considered namespace
+                    # without an __init__.py and are not considered namespace
                     # packages, then simulate a subpackage
-                    path = [os.path.join(path[0], name.rpartition(".")[-1])]
-                    origin = os.path.join(path[0], "__init__.py")
-                    module = self._add_module(name, path=path, parent=parent)
+                    module = self._add_module(
+                        name,
+                        path=[os.path.join(path[0], name.rpartition(".")[-1])],
+                        parent=parent,
+                    )
+                    module.source_is_string = True
                     logging.debug("Adding module [%s] [PACKAGE]", name)
-                    module.code = compile("", origin, "exec")
-                    module.in_import = False
-                    return module
-                spec = None
+                    path = os.path.join(path[0], "__init__.py")
             except Exception:
-                spec = None
-            if spec is None:
+                pass
+            if spec is None and module is None:
                 return None
+        if spec:
             # Handle special cases
             loader = spec.loader
             if loader is importlib.machinery.BuiltinImporter:
@@ -407,16 +408,18 @@ class ModuleFinder:
                 return None
             # Load package or namespace package
             if spec.submodule_search_locations:
-                path_list = list(spec.submodule_search_locations)
-                module = self._add_module(name, path=path_list, parent=parent)
+                module = self._add_module(
+                    name,
+                    path=list(spec.submodule_search_locations),
+                    parent=parent,
+                )
                 if spec.origin in (None, "namespace"):
                     logging.debug("Adding module [%s] [NAMESPACE]", name)
-                    path = os.path.join(path_list[0], "__init__.py")
-                    module.code = compile("", path, "exec")
-                    module.in_import = False
-                    return module
-                logging.debug("Adding module [%s] [PACKAGE]", name)
-                path = spec.origin  # path of __init__
+                    path = str(module.path[0] / "__init__.py")
+                    module.source_is_string = True
+                else:
+                    logging.debug("Adding module [%s] [PACKAGE]", name)
+                    path = spec.origin  # path of __init__.py
                 module.file = path
             else:
                 path = spec.origin
@@ -443,6 +446,8 @@ class ModuleFinder:
                 raise ImportError(f"Bad magic number in {path}", name=name)
         elif isinstance(loader, importlib.machinery.ExtensionFileLoader):
             logging.debug("Adding module [%s] [EXTENSION]", name)
+        elif module.source_is_string:
+            module.code = compile("", path, "exec")
         else:
             raise ImportError(f"Unknown module loader in {path}", name=name)
 
@@ -472,7 +477,7 @@ class ModuleFinder:
         # and is not defined in the module, like 'six' do
         if (
             module.parent is None
-            or module.in_file_system
+            or module.in_file_system >= 1
             or "__package__" in module.global_names
             or code is None
         ):
@@ -565,7 +570,16 @@ class ModuleFinder:
         """
         arguments = []
         imported_module = None
-        for _index, op, arg in dis._unpack_opargs(code.co_code):
+        co_code = code.co_code
+        extended_arg = 0
+        for i in range(0, len(co_code), 2):
+            op = co_code[i]
+            if op >= HAVE_ARGUMENT:
+                arg = co_code[i + 1] | extended_arg
+                extended_arg = (arg << 8) if op == EXTENDED_ARG else 0
+            else:
+                arg = None
+                extended_arg = 0
 
             # keep track of constants (these are used for importing)
             # immediately restart loop so arguments are retained
@@ -674,7 +688,7 @@ class ModuleFinder:
 
     def IncludeModule(self, name: str) -> Module:
         """Include the named module in the frozen executable."""
-        # includes has priority over excludes or []
+        # includes has priority over excludes
         if name in self.excludes and name in self._modules:
             if self._modules[name] is None:
                 self.excludes.pop(name)
