@@ -11,8 +11,6 @@ the environment variable LD_LIBRARY_PATH is only checked at startup.
 import os
 import sys
 
-import BUILD_CONSTANTS
-
 DIR_NAME = os.path.dirname(sys.executable)
 
 paths = os.environ.get("LD_LIBRARY_PATH", "").split(os.pathsep)
@@ -25,25 +23,9 @@ if DIR_NAME not in paths:
 sys.frozen = True
 sys.path = sys.path[:4]
 
-if hasattr(BUILD_CONSTANTS, "TCL_LIBRARY"):
-    os.environ["TCL_LIBRARY"] = os.path.join(
-        DIR_NAME, BUILD_CONSTANTS.TCL_LIBRARY
-    )
 
-if hasattr(BUILD_CONSTANTS, "TK_LIBRARY"):
-    os.environ["TK_LIBRARY"] = os.path.join(
-        DIR_NAME, BUILD_CONSTANTS.TK_LIBRARY
-    )
-
-if hasattr(BUILD_CONSTANTS, "PYTZ_TZDATADIR"):
-    os.environ["PYTZ_TZDATADIR"] = os.path.join(
-        DIR_NAME, BUILD_CONSTANTS.PYTZ_TZDATADIR
-    )
-
-
-def run():
-    name = __name__.rpartition("__init__")[0] + "__main__"
+def run(name):
     code = __loader__.get_code(name)
-    m = __import__("__main__")
-    m.__dict__["__file__"] = code.co_filename
-    exec(code, m.__dict__)
+    module_main = __import__("__main__")
+    module_main.__dict__["__file__"] = code.co_filename
+    exec(code, module_main.__dict__)
